@@ -29,11 +29,11 @@ from typing import Iterator
 from botocore.paginate import Paginator as Boto3Paginator
 
 from .literals import (
-    BatchPredictionFilterVariable,
-    DataSourceFilterVariable,
-    EvaluationFilterVariable,
-    MLModelFilterVariable,
-    SortOrder,
+    BatchPredictionFilterVariableType,
+    DataSourceFilterVariableType,
+    EvaluationFilterVariableType,
+    MLModelFilterVariableType,
+    SortOrderType,
 )
 from .type_defs import (
     DescribeBatchPredictionsOutputTypeDef,
@@ -53,12 +53,12 @@ __all__ = (
 
 class DescribeBatchPredictionsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeBatchPredictions)[Show boto3-stubs documentation](./paginators.md#describebatchpredictionspaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeBatchPredictions)[Show boto3-stubs documentation](./paginators.md#describebatchpredictionspaginator)
     """
 
     def paginate(
         self,
-        FilterVariable: BatchPredictionFilterVariable = None,
+        FilterVariable: BatchPredictionFilterVariableType = None,
         EQ: str = None,
         GT: str = None,
         LT: str = None,
@@ -66,23 +66,23 @@ class DescribeBatchPredictionsPaginator(Boto3Paginator):
         LE: str = None,
         NE: str = None,
         Prefix: str = None,
-        SortOrder: SortOrder = None,
+        SortOrder: SortOrderType = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DescribeBatchPredictionsOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeBatchPredictions.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeBatchPredictions.paginate)
         [Show boto3-stubs documentation](./paginators.md#describebatchpredictionspaginator)
         """
 
 
 class DescribeDataSourcesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeDataSources)[Show boto3-stubs documentation](./paginators.md#describedatasourcespaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeDataSources)[Show boto3-stubs documentation](./paginators.md#describedatasourcespaginator)
     """
 
     def paginate(
         self,
-        FilterVariable: DataSourceFilterVariable = None,
+        FilterVariable: DataSourceFilterVariableType = None,
         EQ: str = None,
         GT: str = None,
         LT: str = None,
@@ -90,23 +90,23 @@ class DescribeDataSourcesPaginator(Boto3Paginator):
         LE: str = None,
         NE: str = None,
         Prefix: str = None,
-        SortOrder: SortOrder = None,
+        SortOrder: SortOrderType = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DescribeDataSourcesOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeDataSources.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeDataSources.paginate)
         [Show boto3-stubs documentation](./paginators.md#describedatasourcespaginator)
         """
 
 
 class DescribeEvaluationsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeEvaluations)[Show boto3-stubs documentation](./paginators.md#describeevaluationspaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeEvaluations)[Show boto3-stubs documentation](./paginators.md#describeevaluationspaginator)
     """
 
     def paginate(
         self,
-        FilterVariable: EvaluationFilterVariable = None,
+        FilterVariable: EvaluationFilterVariableType = None,
         EQ: str = None,
         GT: str = None,
         LT: str = None,
@@ -114,23 +114,23 @@ class DescribeEvaluationsPaginator(Boto3Paginator):
         LE: str = None,
         NE: str = None,
         Prefix: str = None,
-        SortOrder: SortOrder = None,
+        SortOrder: SortOrderType = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DescribeEvaluationsOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeEvaluations.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeEvaluations.paginate)
         [Show boto3-stubs documentation](./paginators.md#describeevaluationspaginator)
         """
 
 
 class DescribeMLModelsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeMLModels)[Show boto3-stubs documentation](./paginators.md#describemlmodelspaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeMLModels)[Show boto3-stubs documentation](./paginators.md#describemlmodelspaginator)
     """
 
     def paginate(
         self,
-        FilterVariable: MLModelFilterVariable = None,
+        FilterVariable: MLModelFilterVariableType = None,
         EQ: str = None,
         GT: str = None,
         LT: str = None,
@@ -138,10 +138,10 @@ class DescribeMLModelsPaginator(Boto3Paginator):
         LE: str = None,
         NE: str = None,
         Prefix: str = None,
-        SortOrder: SortOrder = None,
+        SortOrder: SortOrderType = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DescribeMLModelsOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeMLModels.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeMLModels.paginate)
         [Show boto3-stubs documentation](./paginators.md#describemlmodelspaginator)
         """
