@@ -27,11 +27,11 @@ Usage::
 from botocore.waiter import Waiter as Boto3Waiter
 
 from .literals import (
-    BatchPredictionFilterVariable,
-    DataSourceFilterVariable,
-    EvaluationFilterVariable,
-    MLModelFilterVariable,
-    SortOrder,
+    BatchPredictionFilterVariableType,
+    DataSourceFilterVariableType,
+    EvaluationFilterVariableType,
+    MLModelFilterVariableType,
+    SortOrderType,
 )
 from .type_defs import WaiterConfigTypeDef
 
@@ -45,12 +45,12 @@ __all__ = (
 
 class BatchPredictionAvailableWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/machinelearning.html#MachineLearning.Waiter.batch_prediction_available)[Show boto3-stubs documentation](./waiters.md#batchpredictionavailablewaiter)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/machinelearning.html#MachineLearning.Waiter.batch_prediction_available)[Show boto3-stubs documentation](./waiters.md#batchpredictionavailablewaiter)
     """
 
     def wait(
         self,
-        FilterVariable: BatchPredictionFilterVariable = None,
+        FilterVariable: BatchPredictionFilterVariableType = None,
         EQ: str = None,
         GT: str = None,
         LT: str = None,
@@ -58,25 +58,25 @@ class BatchPredictionAvailableWaiter(Boto3Waiter):
         LE: str = None,
         NE: str = None,
         Prefix: str = None,
-        SortOrder: SortOrder = None,
+        SortOrder: SortOrderType = None,
         NextToken: str = None,
         Limit: int = None,
         WaiterConfig: WaiterConfigTypeDef = None,
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/machinelearning.html#MachineLearning.Waiter.BatchPredictionAvailableWaiter)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/machinelearning.html#MachineLearning.Waiter.BatchPredictionAvailableWaiter)
         [Show boto3-stubs documentation](./waiters.md#batchpredictionavailable)
         """
 
 
 class DataSourceAvailableWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/machinelearning.html#MachineLearning.Waiter.data_source_available)[Show boto3-stubs documentation](./waiters.md#datasourceavailablewaiter)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/machinelearning.html#MachineLearning.Waiter.data_source_available)[Show boto3-stubs documentation](./waiters.md#datasourceavailablewaiter)
     """
 
     def wait(
         self,
-        FilterVariable: DataSourceFilterVariable = None,
+        FilterVariable: DataSourceFilterVariableType = None,
         EQ: str = None,
         GT: str = None,
         LT: str = None,
@@ -84,25 +84,25 @@ class DataSourceAvailableWaiter(Boto3Waiter):
         LE: str = None,
         NE: str = None,
         Prefix: str = None,
-        SortOrder: SortOrder = None,
+        SortOrder: SortOrderType = None,
         NextToken: str = None,
         Limit: int = None,
         WaiterConfig: WaiterConfigTypeDef = None,
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/machinelearning.html#MachineLearning.Waiter.DataSourceAvailableWaiter)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/machinelearning.html#MachineLearning.Waiter.DataSourceAvailableWaiter)
         [Show boto3-stubs documentation](./waiters.md#datasourceavailable)
         """
 
 
 class EvaluationAvailableWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/machinelearning.html#MachineLearning.Waiter.evaluation_available)[Show boto3-stubs documentation](./waiters.md#evaluationavailablewaiter)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/machinelearning.html#MachineLearning.Waiter.evaluation_available)[Show boto3-stubs documentation](./waiters.md#evaluationavailablewaiter)
     """
 
     def wait(
         self,
-        FilterVariable: EvaluationFilterVariable = None,
+        FilterVariable: EvaluationFilterVariableType = None,
         EQ: str = None,
         GT: str = None,
         LT: str = None,
@@ -110,25 +110,25 @@ class EvaluationAvailableWaiter(Boto3Waiter):
         LE: str = None,
         NE: str = None,
         Prefix: str = None,
-        SortOrder: SortOrder = None,
+        SortOrder: SortOrderType = None,
         NextToken: str = None,
         Limit: int = None,
         WaiterConfig: WaiterConfigTypeDef = None,
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/machinelearning.html#MachineLearning.Waiter.EvaluationAvailableWaiter)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/machinelearning.html#MachineLearning.Waiter.EvaluationAvailableWaiter)
         [Show boto3-stubs documentation](./waiters.md#evaluationavailable)
         """
 
 
 class MLModelAvailableWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/machinelearning.html#MachineLearning.Waiter.ml_model_available)[Show boto3-stubs documentation](./waiters.md#mlmodelavailablewaiter)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/machinelearning.html#MachineLearning.Waiter.ml_model_available)[Show boto3-stubs documentation](./waiters.md#mlmodelavailablewaiter)
     """
 
     def wait(
         self,
-        FilterVariable: MLModelFilterVariable = None,
+        FilterVariable: MLModelFilterVariableType = None,
         EQ: str = None,
         GT: str = None,
         LT: str = None,
@@ -136,12 +136,12 @@ class MLModelAvailableWaiter(Boto3Waiter):
         LE: str = None,
         NE: str = None,
         Prefix: str = None,
-        SortOrder: SortOrder = None,
+        SortOrder: SortOrderType = None,
         NextToken: str = None,
         Limit: int = None,
         WaiterConfig: WaiterConfigTypeDef = None,
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/machinelearning.html#MachineLearning.Waiter.MLModelAvailableWaiter)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/machinelearning.html#MachineLearning.Waiter.MLModelAvailableWaiter)
         [Show boto3-stubs documentation](./waiters.md#mlmodelavailable)
         """
